'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runHowdoi = exports.retrieveHowdoiOutput = void 0;
const cp = require("child_process");
const events_1 = require("events");
const plugin_interfaces_1 = require("./plugin_interfaces");
const removeRegex = require("./remove_regexes");
const findAttr = require("./find_attributes");
const createAttr = require("./create_attributes");
function retrieveHowdoiOutput(command, numFlagVal) {
    return __awaiter(this, void 0, void 0, function* () {
        /* This function spawns an external application in a new process to run the howdoi query and returns
        the howdoi query answer formatted as a JSONObj[] */
        const numFlag = '-n' + String(numFlagVal);
        const process = cp.spawn(plugin_interfaces_1.HOWDOI_PREFIX, [command, numFlag, '-j']);
        let howdoiJSON = [{ answer: '', link: '', position: '' }];
        process.stdout.on('data', (data) => {
            howdoiJSON = JSON.parse(data);
        });
        process.stderr.on('dataErr', (dataErr) => {
            console.log(`stderr: ${dataErr}`);
        });
        process.on('error', (error) => {
            console.log(`error: ${error.message}`);
        });
        process.on('close', (code) => {
            console.log(`child process exited with code ${code}`);
        });
        // Wait for the child process to exit
        const endProcess = yield events_1.once(process, 'close');
        try {
            endProcess;
        }
        catch (e) {
            throw Error('Invalid json object or no json object returned');
        }
        return howdoiJSON;
    });
}
exports.retrieveHowdoiOutput = retrieveHowdoiOutput;
function runHowdoi(userCommand) {
    return __awaiter(this, void 0, void 0, function* () {
        /* This functions modifies the users command while checking for errors
        and formats the howdoi query answer into a HowdoiObj*/
        let commentChar;
        // check if query is enclosed by a single line comment and return commentChar
        try {
            // retrieve single line comment and store in CommentChars obj
            commentChar = findAttr.findCommentChar(userCommand);
        }
        catch (e) {
            throw new ReferenceError('Invalid line comment. Please use single line comment for howdoi.');
        }
        const commandWithoutComment = removeRegex.removeCommentChar(userCommand, commentChar);
        let commandWithoutPrefix;
        // check if howdoi prefix is present and remove it
        try {
            commandWithoutPrefix = removeRegex.removeHowdoiPrefix(commandWithoutComment);
        }
        catch (e) {
            throw new SyntaxError('Place "howdoi" in front of query');
        }
        let numFlagVal;
        // check if -n flag is present and remove it
        try {
            numFlagVal = findAttr.findNumFlagVal(commandWithoutPrefix);
        }
        catch (e) {
            throw new RangeError('Invalid num flag value');
        }
        const commandWithoutFlag = removeRegex.removeNumFlag(commandWithoutPrefix);
        let parsedJson;
        // check if howdoi output is valid and save the JSON Obj
        try {
            parsedJson = yield retrieveHowdoiOutput(commandWithoutFlag, numFlagVal);
        }
        catch (e) {
            throw new Error('Invalid json object or no json object returned');
        }
        let howdoiResultObj = createAttr.createHowdoiObj(parsedJson, userCommand, commentChar);
        howdoiResultObj = removeRegex.removeInlineRegex(howdoiResultObj);
        return howdoiResultObj;
    });
}
exports.runHowdoi = runHowdoi;
//# sourceMappingURL=plugin.js.map