'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeInlineRegex = exports.removeNumFlag = exports.removeHowdoiPrefix = exports.removeCommentChar = void 0;
const plugin_interfaces_1 = require("./plugin_interfaces");
function removeCommentChar(userCommand, commentChar) {
    /* This function removes the single line comment regex from the userCommand and returns it*/
    const frontCommentChar = commentChar.frontComment;
    const endCommentChar = commentChar.endComment;
    if (!userCommand.includes(endCommentChar)) {
        return userCommand.replace(frontCommentChar, '').trim();
    }
    userCommand = userCommand.replace(frontCommentChar, '');
    return userCommand.replace(endCommentChar, '').trim();
}
exports.removeCommentChar = removeCommentChar;
function removeHowdoiPrefix(command) {
    // removes the prefix `howdoi` from the string
    if (!command.trim().startsWith(plugin_interfaces_1.HOWDOI_PREFIX)) {
        throw Error('Place "howdoi" in front of query');
    }
    return command.replace(plugin_interfaces_1.HOWDOI_PREFIX, '').trim();
}
exports.removeHowdoiPrefix = removeHowdoiPrefix;
function removeNumFlag(userCommand) {
    /* This function removes the numFlag value within the userCommand and returns userCommand */
    const numFlag = '-n';
    const index = userCommand.indexOf(numFlag);
    if (index === -1) {
        return userCommand;
    }
    const commandWithoutNumFlag = userCommand.slice(0, index).trim();
    return commandWithoutNumFlag;
}
exports.removeNumFlag = removeNumFlag;
function removeInlineRegex(howdoiResultObj) {
    /* This function returns a HowdoiObj that has the arrow and dot regexes removed
    from the answer array to display inline code more cleanly */
    const arrowRegex = /[>->->]{3}/g;
    const dotRegex = /[.-.-.]{3}/g;
    for (let i = 0; i < howdoiResultObj.answer.length; i++) {
        if (howdoiResultObj.answer[i].match(arrowRegex)) {
            howdoiResultObj.answer[i] = howdoiResultObj.answer[i].replace(arrowRegex, '').trim();
        }
        if (howdoiResultObj.answer[i].match(dotRegex)) {
            howdoiResultObj.answer[i] = howdoiResultObj.answer[i].replace(dotRegex, '').trim();
        }
    }
    return howdoiResultObj;
}
exports.removeInlineRegex = removeInlineRegex;
//# sourceMappingURL=remove_regexes.js.map