"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const vscode = require("vscode");
const plugin = require("./code-editor-integration/src/plugin");
function activate(context) {
    let disposable = vscode.commands.registerCommand('howdoi.extension', () => __awaiter(this, void 0, void 0, function* () {
        const editor = vscode.window.activeTextEditor;
        if (!editor) {
            vscode.window.showInformationMessage('create a file to enable howdoi');
            return;
        }
        const userCommand = editor.document.getText(editor.selection).trim();
        let howdoiResultObj;
        try {
            howdoiResultObj = yield plugin.runHowdoi(userCommand);
        }
        catch (e) {
            if (e instanceof ReferenceError) {
                vscode.window.showInformationMessage('Invalid line comment. Please use single line comment for howdoi.');
                return e;
            }
            else if (e instanceof SyntaxError) {
                vscode.window.showInformationMessage('Place "howdoi" in front of query');
                return e;
            }
            else if (e instanceof RangeError) {
                vscode.window.showInformationMessage('Invalid num flag value');
                return e;
            }
            else if (e instanceof Error) {
                vscode.window.showInformationMessage('Could not find response for query');
                return e;
            }
            else {
                vscode.window.showInformationMessage('Error. Try again');
                return e;
            }
        }
        quickPicker(editor, howdoiResultObj, userCommand);
    }));
    context.subscriptions.push(disposable);
}
exports.activate = activate;
function quickPicker(editor, howdoiResultObj, userCommand) {
    const quickPick = vscode.window.createQuickPick();
    quickPick.items = howdoiResultObj.answer.map((answer) => ({ label: answer, link: howdoiResultObj.link[howdoiResultObj.answer.indexOf(answer)] }));
    quickPick.onDidChangeSelection(([item]) => {
        if (item) {
            editor.edit((edit) => {
                edit.replace(editor.selection, userCommand + '\n' + item.link + '\n' + item.label);
            });
            quickPick.dispose();
        }
    });
    quickPick.onDidHide(() => quickPick.dispose());
    quickPick.show();
}
function deactivate() { }
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map